@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_VERSION_H__
-#define __GTK_SOURCE_VERSION_H__
+#ifndef GTK_SOURCE_VERSION_H
+#define GTK_SOURCE_VERSION_H
 
 #include <glib.h>
 
@@ -46,7 +46,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MINOR_VERSION (20)
+#define GTK_SOURCE_MINOR_VERSION (22)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -57,7 +57,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MICRO_VERSION (3)
+#define GTK_SOURCE_MICRO_VERSION (2)
 
 
 /**
@@ -197,6 +197,16 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_3_20 (G_ENCODE_VERSION (3, 20))
 
+/**
+ * GTK_SOURCE_VERSION_3_22:
+ *
+ * A macro that evaluates to the 3.22 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 3.22
+ */
+#define GTK_SOURCE_VERSION_3_22 (G_ENCODE_VERSION (3, 22))
+
 #ifndef __GTK_DOC_IGNORE__
 #if (GTK_SOURCE_MINOR_VERSION % 2)
 #define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION, GTK_SOURCE_MINOR_VERSION + 1))
@@ -474,6 +484,24 @@ G_BEGIN_DECLS
 #endif
 #endif /* __GTK_DOC_IGNORE__ */
 
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MIN_REQUIRED >= GTK_SOURCE_VERSION_3_22
+#define GTK_SOURCE_DEPRECATED_IN_3_22 G_DEPRECATED _GTK_SOURCE_EXTERN
+#define GTK_SOURCE_DEPRECATED_IN_3_22_FOR(f) G_DEPRECATED_FOR(f) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_DEPRECATED_IN_3_22 _GTK_SOURCE_EXTERN
+#define GTK_SOURCE_DEPRECATED_IN_3_22_FOR(f) _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_3_22
+#define GTK_SOURCE_AVAILABLE_IN_3_22 G_UNAVAILABLE(3, 22) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_AVAILABLE_IN_3_22 _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
 GTK_SOURCE_AVAILABLE_IN_3_20
 guint		gtk_source_get_major_version		(void);
 
@@ -490,4 +518,4 @@ gboolean	gtk_source_check_version		(guint major,
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_VERSION_H__ */
+#endif /* GTK_SOURCE_VERSION_H */
